package gpsys.cos;

import gpsys.*;

/**
 * <pre>
 *	Vector2Mod10 Right
 * </pre>
 *
 * A Terminal that instructs the terrainrobot to turn right by 90 degrees.
 *
 * @see			gpsys.Primitive
 * @see			gpsys.Terminal
 *
 * @version             1.1, 24 Mars 1999
 * @author      <a href="mailto:epierre@e-nef.com">Emmanuel PIERRE</a>
 *                      <address>DEA IARFA,</address>
 */
public class Right extends Terminal {
	/**
	 * The terrainrobot being controlled.
	 */
	private Robot robot;

	/**
	 * Create a new Right terminal which controls the specified terrain robot.
	 *
	 * @param robot The robot to be controlled.
	 */
	public Right(Robot robot) {
		this.type = CosSimTypes.Vector2Mod10;
		this.robot	= robot;
	}
		
	/**
	 * Evaluates this Terminal, causing the robot nothing but live longer !
	 *
	 * @param i			The individual being evaluated.
	 *
	 * @return	An Object (actually a Vector2Mod10) representing the
	 * 			Zero Vector2Mod10.
	 */
	public final Object evaluateObject(Individual i) {
		robot.right();
		return Vector2Mod10.Zero;
	}

	/**
	 * Creates a new instance of this Object.
	 *
	 * @return	A reference to this same Object since none of the instance
	 *			variables are to be changed.
	 */
	public final Primitive instance() {
		return this;
	}

	/**
	 * Returns a String representation of this Terminal.
	 *
	 * @return A String containing the name of the Terminal.
	 */
	public String toString() {
		return "RIGHT";
	}
}
